@@ -1,5 +1,4 @@
 from diffgram.core.directory import Directory
-from diffgram.pytorch_diffgram.diffgram_pytorch_dataset import DiffgramPytorchDataset
 from diffgram.tensorflow_diffgram.diffgram_tensorflow_dataset import DiffgramTensorflowDataset
 import urllib
 
@@ -15,16 +14,7 @@ class SlicedDirectory(Directory):
         super(Directory, self).__init__(self.client, self.file_id_list)
 
     def all_file_ids(self):
-        page_num = 1
-        result = []
-        while page_num is not None:
-            diffgram_files = self.list_files(limit = 1000,
-                                             page_num = page_num,
-                                             file_view_mode = 'ids_only',
-                                             query = self.query)
-            page_num = self.file_list_metadata['next_page']
-            result = result + diffgram_files
-        return result
+        return super().all_file_ids(query = self.query)
 
     def explore(self):
 
@@ -46,7 +36,7 @@ class SlicedDirectory(Directory):
             Transforms the file list inside the dataset into a pytorch dataset.
         :return:
         """
-
+        from diffgram.pytorch_diffgram.diffgram_pytorch_dataset import DiffgramPytorchDataset
         pytorch_dataset = DiffgramPytorchDataset(
             project = self.client,
             diffgram_file_id_list = self.file_id_list,
